@@ -1,4 +1,4 @@
-allbetas <- function(y, x, pvalue = FALSE) {
+allbetas <- function(y, x, pvalue = FALSE, logged = FALSE) {
 
   if ( min(y) > 0 & max(y) < 1) {
     y <- log( y / (1 - y) )
@@ -28,10 +28,12 @@ allbetas <- function(y, x, pvalue = FALSE) {
     sy <- sd(y)
     rho <- r / ( sqrt(sx) * sy)
     sqdof <- sqrt(n - 2)
-    ta <- rho * sqdof / sqrt(1 - rho^2)
-    pvalue <- 2 * pt( abs(ta), n - 2, lower.tail = FALSE)
+    stat <- rho * sqdof / sqrt(1 - rho^2)
+    if ( logged == TRUE ){
+      pvalue <- log(2) + pt( abs(stat), n - 2, lower.tail = FALSE, log.p = TRUE)
+    } else pvalue <- 2 * pt( abs(stat), n - 2, lower.tail = FALSE)
 
-    result <- cbind(a, be, rho, pvalue)
+    result <- cbind(a, be, rho, stat, pvalue)
 
     if ( is.null( colnames(x) ) ) {
       rownames(result) <- paste("X", 1:ncol(x), sep = "" )
